mocks

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type GitConfigParser

type GitConfigParser struct {
	mock.Mock
}

GitConfigParser is an autogenerated mock type for the ConfigParserInterface type

func NewGitConfigParser

func NewGitConfigParser(t interface {
	mock.TestingT
	Cleanup(func())
}) *GitConfigParser

NewGitConfigParser creates a new instance of GitConfigParser. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GitConfigParser) GetSectionOption

func (_m *GitConfigParser) GetSectionOption(_a0 string, _a1 string) string

GetSectionOption provides a mock function with given fields: _a0, _a1

func (*GitConfigParser) LoadConfig

func (_m *GitConfigParser) LoadConfig(_a0 config.Scope) (*config.Config, error)

LoadConfig provides a mock function with given fields: _a0

func (*GitConfigParser) SetConfig

func (_m *GitConfigParser) SetConfig(_a0 *config.Config)

SetConfig provides a mock function with given fields: _a0

type GpgEntityAccessor

type GpgEntityAccessor struct {
	mock.Mock
}

GpgEntityAccessor is an autogenerated mock type for the EntityAccessorInterface type

func NewGpgEntityAccessor

func NewGpgEntityAccessor(t interface {
	mock.TestingT
	Cleanup(func())
}) *GpgEntityAccessor

NewGpgEntityAccessor creates a new instance of GpgEntityAccessor. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GpgEntityAccessor) GetEntity

func (_m *GpgEntityAccessor) GetEntity(_a0 string, _a1 string) (*openpgp.Entity, error)

GetEntity provides a mock function with given fields: _a0, _a1

type GpgEntityReader

type GpgEntityReader struct {
	mock.Mock
}

GpgEntityReader is an autogenerated mock type for the EntityReaderInterface type

func NewGpgEntityReader

func NewGpgEntityReader(t interface {
	mock.TestingT
	Cleanup(func())
}) *GpgEntityReader

NewGpgEntityReader creates a new instance of GpgEntityReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*GpgEntityReader) GetPrivateKey

func (_m *GpgEntityReader) GetPrivateKey(_a0 string, _a1 string) (string, error)

GetPrivateKey provides a mock function with given fields: _a0, _a1

func (*GpgEntityReader) ReadArmoredKeyRing

func (_m *GpgEntityReader) ReadArmoredKeyRing(_a0 string) (openpgp.EntityList, error)

ReadArmoredKeyRing provides a mock function with given fields: _a0

type ReleaseGetter

type ReleaseGetter struct {
	mock.Mock
}

ReleaseGetter is an autogenerated mock type for the ReleaseGetterInterface type

func NewReleaseGetter

func NewReleaseGetter(t interface {
	mock.TestingT
	Cleanup(func())
}) *ReleaseGetter

NewReleaseGetter creates a new instance of ReleaseGetter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*ReleaseGetter) Get

func (_m *ReleaseGetter) Get(_a0 string) (*http.Response, error)

Get provides a mock function with given fields: _a0

type Repository

type Repository struct {
	mock.Mock
}

Repository is an autogenerated mock type for the RepositoryInterface type

func NewRepository

func NewRepository(t interface {
	mock.TestingT
	Cleanup(func())
}) *Repository

NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Repository) ConfigScoped

func (_m *Repository) ConfigScoped(_a0 config.Scope) (*config.Config, error)

ConfigScoped provides a mock function with given fields: _a0

func (*Repository) CreateTag

func (_m *Repository) CreateTag(_a0 string, _a1 plumbing.Hash, _a2 *v5.CreateTagOptions) (*plumbing.Reference, error)

CreateTag provides a mock function with given fields: _a0, _a1, _a2

func (*Repository) Worktree

func (_m *Repository) Worktree() (*v5.Worktree, error)

Worktree provides a mock function with given fields:

type Semver

type Semver struct {
	mock.Mock
}

Semver is an autogenerated mock type for the SemverInterface type

func NewSemver

func NewSemver(t interface {
	mock.TestingT
	Cleanup(func())
}) *Semver

NewSemver creates a new instance of Semver. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Semver) IncMajor

func (_m *Semver) IncMajor() semver.Version

IncMajor provides a mock function with given fields:

func (*Semver) IncMinor

func (_m *Semver) IncMinor() semver.Version

IncMinor provides a mock function with given fields:

func (*Semver) IncPatch

func (_m *Semver) IncPatch() semver.Version

IncPatch provides a mock function with given fields:

func (*Semver) Metadata

func (_m *Semver) Metadata() string

Metadata provides a mock function with given fields:

func (*Semver) Prerelease

func (_m *Semver) Prerelease() string

Prerelease provides a mock function with given fields:

func (*Semver) SetMetadata

func (_m *Semver) SetMetadata(_a0 string) (semver.Version, error)

SetMetadata provides a mock function with given fields: _a0

func (*Semver) SetPrerelease

func (_m *Semver) SetPrerelease(_a0 string) (semver.Version, error)

SetPrerelease provides a mock function with given fields: _a0

func (*Semver) String

func (_m *Semver) String() string

String provides a mock function with given fields:

type Worktree

type Worktree struct {
	mock.Mock
}

Worktree is an autogenerated mock type for the WorktreeInterface type

func NewWorktree

func NewWorktree(t interface {
	mock.TestingT
	Cleanup(func())
}) *Worktree

NewWorktree creates a new instance of Worktree. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Worktree) Add

func (_m *Worktree) Add(_a0 string) (plumbing.Hash, error)

Add provides a mock function with given fields: _a0

func (*Worktree) Commit

func (_m *Worktree) Commit(_a0 string, _a1 *v5.CommitOptions) (plumbing.Hash, error)

Commit provides a mock function with given fields: _a0, _a1

Jump to