Documentation
¶
Index ¶
- type GitConfigParser
- type GpgEntityAccessor
- type GpgEntityReader
- type ReleaseGetter
- type Repository
- type Semver
- func (_m *Semver) IncMajor() semver.Version
- func (_m *Semver) IncMinor() semver.Version
- func (_m *Semver) IncPatch() semver.Version
- func (_m *Semver) Metadata() string
- func (_m *Semver) Prerelease() string
- func (_m *Semver) SetMetadata(_a0 string) (semver.Version, error)
- func (_m *Semver) SetPrerelease(_a0 string) (semver.Version, error)
- func (_m *Semver) String() string
- type Worktree
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GitConfigParser ¶
GitConfigParser is an autogenerated mock type for the ConfigParserInterface type
func NewGitConfigParser ¶
func NewGitConfigParser(t interface {
mock.TestingT
Cleanup(func())
}) *GitConfigParser
NewGitConfigParser creates a new instance of GitConfigParser. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*GitConfigParser) GetSectionOption ¶
func (_m *GitConfigParser) GetSectionOption(_a0 string, _a1 string) string
GetSectionOption provides a mock function with given fields: _a0, _a1
func (*GitConfigParser) LoadConfig ¶
LoadConfig provides a mock function with given fields: _a0
func (*GitConfigParser) SetConfig ¶
func (_m *GitConfigParser) SetConfig(_a0 *config.Config)
SetConfig provides a mock function with given fields: _a0
type GpgEntityAccessor ¶
GpgEntityAccessor is an autogenerated mock type for the EntityAccessorInterface type
func NewGpgEntityAccessor ¶
func NewGpgEntityAccessor(t interface {
mock.TestingT
Cleanup(func())
}) *GpgEntityAccessor
NewGpgEntityAccessor creates a new instance of GpgEntityAccessor. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
type GpgEntityReader ¶
GpgEntityReader is an autogenerated mock type for the EntityReaderInterface type
func NewGpgEntityReader ¶
func NewGpgEntityReader(t interface {
mock.TestingT
Cleanup(func())
}) *GpgEntityReader
NewGpgEntityReader creates a new instance of GpgEntityReader. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*GpgEntityReader) GetPrivateKey ¶
func (_m *GpgEntityReader) GetPrivateKey(_a0 string, _a1 string) (string, error)
GetPrivateKey provides a mock function with given fields: _a0, _a1
func (*GpgEntityReader) ReadArmoredKeyRing ¶
func (_m *GpgEntityReader) ReadArmoredKeyRing(_a0 string) (openpgp.EntityList, error)
ReadArmoredKeyRing provides a mock function with given fields: _a0
type ReleaseGetter ¶
ReleaseGetter is an autogenerated mock type for the ReleaseGetterInterface type
func NewReleaseGetter ¶
func NewReleaseGetter(t interface {
mock.TestingT
Cleanup(func())
}) *ReleaseGetter
NewReleaseGetter creates a new instance of ReleaseGetter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
type Repository ¶
Repository is an autogenerated mock type for the RepositoryInterface type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) ConfigScoped ¶
ConfigScoped provides a mock function with given fields: _a0
type Semver ¶
Semver is an autogenerated mock type for the SemverInterface type
func NewSemver ¶
NewSemver creates a new instance of Semver. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Semver) Prerelease ¶
Prerelease provides a mock function with given fields:
func (*Semver) SetMetadata ¶
SetMetadata provides a mock function with given fields: _a0
func (*Semver) SetPrerelease ¶
SetPrerelease provides a mock function with given fields: _a0
type Worktree ¶
Worktree is an autogenerated mock type for the WorktreeInterface type
func NewWorktree ¶
NewWorktree creates a new instance of Worktree. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.